@@ -20,12 +20,12 @@
 
 import astropy.units as u
 import numpy as np
+import stqdm  # See also https://github.com/tqdm/tqdm
 import streamlit as st
 from astropy.coordinates import Distance, SkyCoord, SphericalRepresentation
 from callbacks import load_or_delete_fittings
 from config import (app_styles, config_sliders, selected_bodies,
                     selected_imagers)
-from extensions.stqdm import stqdm  # See also https://github.com/tqdm/tqdm
 from geometrical_models import ellipsoid, gcs, spheroid
 from modules import (date_and_event_selection, final_parameters_gmodel,
                      fitting_and_slider_options_container, fitting_sliders,
@@ -137,7 +137,7 @@ def run():
         long_val = [-180., 180.]
 
     if 'longit' not in st.session_state:
-        st.session_state.longit = 0
+        st.session_state.longit = 0.
     longit = st.sidebar.slider(f'{st.session_state.coord_system} \
                                Longitude [deg.]:',
                                min_value=long_val[0],
@@ -145,7 +145,7 @@ def run():
                                step=0.01, key='longit') * u.degree
 
     if 'latitu' not in st.session_state:
-        st.session_state.latitu = 0
+        st.session_state.latitu = 0.
     latitu = st.sidebar.slider(f'{st.session_state.coord_system} \
                                Latitude [deg.]:',
                                min_value=-90.,
@@ -171,7 +171,7 @@ def run():
                                                kwargs={'vars': ['map', ]})
         select_timerange_form = st.form(key='select_timerange_form')
         imaging_time_range = select_timerange_form.slider('Time Range [hours]',
-                                                          -1., 6., [-1., 1.], 0.5,
+                                                          -3., 6., [-1., 1.], 0.5,
                                                           key='imaging_time_range')
         select_timerange_form.form_submit_button(label='Submit',
                                                  on_click=delete_from_state,
